@@ -1,4 +1,5 @@
-package tool::M4;
+package
+  tool::M4;
 use strict;
 use warnings;
 use base qw( Alien::Base );
